/*
 * Class: Configuration
 *
 * $Id: Configuration.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr;

import org.w3c.dom.Element;


/**
 * This class is used for setting a new configuration or getting info
 * about a given one. The information handled by this class includes a
 * binding for the configuration, the associated ruleset, and the
 * protocol used.
 *
 * @author kan, macias
 */
public class Configuration {
    /** A binding for this config. */
    String binding;

    /** The associated ruleset */
    Element ruleset;

    /** Environment section of the configuration */
    Element environment;

    /** The protocol used in the configuration */
    Element confProtocol;

    /** Unique constructor for this class; it sets the binding with a <b>null</b> protocol definition.

       @param binding is a String with the binding name for this class */
    public Configuration(String binding) {
        this.binding = binding;
        confProtocol = null;
    }

    /** Sets (changes) a (the) binding for the given configuration
       @param name The name of the binding
       */
    public void setBinding(String name) {
        binding = name;
    }

    /** Returns a String containing the name of the binding for this configuration */
    public String getBinding() {
        return binding;
    }

    /** Returns the Ruleset associated with this configuration
        @return the ruleset for this configuration  */
    public Element getRuleset() {
        return ruleset;
    }

    /** Sets a ruleset with the rules provided.
        @param rules the {@link es.rediris.aarr.rules.Ruleset rules} being provided  */
    public void setRuleset(Element rules) {
        ruleset = rules;
    }

    /** Returns the Environment section in a configuration
        @return the environment for the actual configuration  */
    public Element getEnvironment() {
        return ruleset;
    }

    /** Sets the value of the element containing environment variables
        @param envir the environment extracted from the configuration  */
    public void setEnvironment(Element envir) {
        environment = envir;
    }

    /** Returns the protocol associated with the configuration
        @return the protocol */
    public Element getConfigProtocol() {
        return confProtocol;
    }

    /** Sets the protocol in the configuration to the provided one
        @param conf the protocol
        */
    public void setConfigProtocol(Element conf) {
        confProtocol = conf;
    }
}
