/*
 * Class: Diagnostic
 *
 * $Id: Diagnostic.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr;

import org.apache.log4j.Logger;
import org.apache.log4j.xml.DOMConfigurator;


/**
 * This class is used for logging purposes. It inits a Log4Java Logger with an specific configuration and writes logs according to the provided log level.
 *
 * @author kan, macias
 */
public class Diagnostic {
    /** INFO log level mode */
    public static final int INFO_MODE = 0;

    /** ERROR log level mode */
    public static final int WARNING_MODE = 1;

    /** SEVERE log level mode */
    public static final int SEVERE_MODE = 2;

    /** DEBUG log level mode */
    public static final int DEBUG_MODE = 3;

    /** A Log4Java logger  ( more info at: <a href="http://logging.apache.org/log4j/docs/">http://logging.apache.org/log4j/docs/</a> ) */
    private static Logger logger = Logger.getLogger(Diagnostic.class.getName());

    /** The unique constructor is used to call the {@link Diagnostic#initLog4Java initLog4Java()} method */
    public Diagnostic() {
        initLog4Java();
    }

    /** Configures the Logger */
    private void initLog4Java() {
        DOMConfigurator.configure("conf/log4j.xml");
    }

    /** Write messages using the logger and the given mode
      @param mode is a integer specifying the logging mode ({@link Diagnostic#INFO_MODE INFO_MODE}, {@link Diagnostic#WARNING_MODE WARNING_MODE}, {@link Diagnostic#SEVERE_MODE SEVERE_MODE} or {@link Diagnostic#DEBUG_MODE DEBUG_MODE})
      @param message is the messaged to be logged */
    public static void writeLog(int mode, String message) {
        switch (mode) {
        case INFO_MODE:
            logger.info(message);

            break;

        case WARNING_MODE:
            logger.warn(message);

            break;

        case SEVERE_MODE:
            logger.fatal(message);

            break;

        default:
            logger.debug(message);
        }
    }
}
