/*
 * Class: ActionNext
 *
 * $Id: ActionNext.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.rules;

import org.w3c.dom.Element;


/**
 * This class extends a {@link Action Action} and is used to create and modify
 * an action that is not a {@link ActionFinish finish} or {@link ActionSend send}.
 *
 * @author kan, macias
 */
public class ActionNext extends Action {
    /** Stores the name for this ActionNext object */
    String name;

    /** Stores the value for this ActionNext object */
    String state;

    /** The class constructor sets the name and value of this ActionNext from the
    attributes "name" and "next" of the given condition element
    @param cond A condition (in a <code>org.w3c.dom.Element</code> form */
    public ActionNext(Element cond) {
        String name = cond.getAttribute("name");

        if (name == null) {
            name = "";
        }

        setName(name);

        String defaultValue = cond.getAttribute("next");
        setNextState(defaultValue);
    }

    /** Gets the name of the actual ActionNext
    @return A string with the name */
    public String getName() {
        return name;
    }

    /** Sets the name for the actual ActionNext
    @param name A String containing the new name */
    public void setName(String name) {
        this.name = name;
    }

    /** Return the name for the next state
    @return A <code>String</code> with the name */
    public String getNextState() {
        return state;
    }

    /** Sets the name of the next state
    @param state The name of the state*/
    public void setNextState(String state) {
        this.state = state;
    }

    /** Executes the action, reporting the result to the {@link es.rediris.aarr.Diagnostic diagnostics} module.

    @return A string with the name of next state */
    public String execute() {
        return getNextState();
    }

    /** Always return false, because there are more actions

    @return A boolean with the response (always false for and ActionNext) */
    public boolean isEndState() {
        return false;
    }
}
