/*
 * Class: ActionSend
 *
 * $Id: ActionSend.java,v 1.2 2005/05/26 14:51:12 macias Exp $
 */
package es.rediris.aarr.rules;

import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import java.util.Iterator;
import java.util.Vector;


/**
 * For a given condition sets the name of the condition, read all the fields in
 * the condition and separates and stores their value, key and base.
 *
 * @author kan, macias
 */
public class ActionSend extends Action {
    /** The name of this ActionSend object */
    private String name;
    
    /** An array with the ids */
    private String [] ids;
    
    /** An array containing values associated with the ids */
    private String [] values;
    
    /** The keys (strings) */
    private String [] keys;
    
    /** The bases (also strings) */
    private String [] bases;
    
    /** The class constructor sets the name of this ActionSend from the
     *  attribute "name" and then gets all fields (with its ids, values, keys,
     * and bases) within the condition <code>org.w3c.dom.Element</code> passed
     *
     * @param cond A condition (in a <code>org.w3c.dom.Element</code> form */
    public ActionSend(Element cond) {
        String name = cond.getAttribute("name");
        
        if (name == null) {
            name = "";
        }
        
        setName(name);
        
        NodeList list = cond.getElementsByTagName("field");
        
        ids = new String[ list.getLength() ];
        values = new String[ list.getLength() ];
        keys = new String[ list.getLength() ];
        bases = new String[ list.getLength() ];
        
        for (int i = 0; i < list.getLength(); i++) {
            Element elem = (Element) list.item(i);
            
            ids[i] = elem.getAttribute("id");
            
            if (elem.hasAttribute("value")) {
                values[i] =   elem.getAttribute("value");
            }
            
            if (elem.hasAttribute("key")) {
                keys[i] = elem.getAttribute("key");
            }
            
            if (elem.hasAttribute("base")) {
                bases[i] = elem.getAttribute("base");
            }
        }
    }
    
    /** Returns the name of this ActionSend object
     * @return A string with the name for this Action */
    public String getName() {
        return name;
    }
    
    /** Sets the name for the actual ActionSend
     *
     * @param name A String containing the new name */
    public void setName(String name) {
        this.name = name;
    }
    
    /** Executes the action, passing the result to the {@link RuleProcessor#putOutput(String [] ids , String [] values) putOutput method}
     * in a {@link RuleProcessor RuleProcessor} } .
     *
     * @return Null for an ActionSend  */
    public String execute() {
        
        RuleProcessor.putOutput(ids, values);
        
        return null;
    }
    
    /** Always return false, because there are more actions
     *
     * @return A boolean with the response (always false for and ActionSend) */
    public boolean isEndState() {
        return false;
    }
}
