/*
 * Class: ConditionReceive
 *
 * $Id: ConditionReceive.java,v 1.3 2005/05/26 15:48:47 macias Exp $
 */
package es.rediris.aarr.rules;

import es.rediris.aarr.Diagnostic;

import org.w3c.dom.Element;


/**
 *  This class extends a {@link Condition Condition} and is used to create and modify
 * a condition "receive". The class stores the name of the condition, and the property "received"
 *
 * @author kan, macias
 */
public class ConditionReceive extends Condition {
    /** The name of this condition */
    String name;
    
    /** A <code>java.lang.String</code> with the value of attribute "received" */
    String received;
    
    /** The constructor for this class receives a <code>org.w3c.dom.Element</code> that should
     * contain two attributes, "name" and "receive". The attribute values are stored into {@link ConditionReceive#name ConditionReceive.name}
     * and {@link ConditionReceive#received ConditionReceive.received}
     *
     * @param cond A <code>org.w3c.dom.Element</code> specifying a condition */
    public ConditionReceive(Element cond) {
        String name = cond.getAttribute("name");
        
        if (name == null) {
            name = "";
        }
        
        setName(name);
        
        String receiveValue = cond.getAttribute("receive");
        setReceived(receiveValue);
    }
    
    /** Gets the name of this Condition */
    public String getName() {
        return name;
    }
    
    /** Sets a name for this condition */
    public void setName(String name) {
        this.name = name;
    }
    
    /** Returns the value of the {@link ConditionReceive#received received} variable
     *
     * @return A string with the value of the {@link ConditionReceive#received received} variable */
    public String getReceived() {
        return received;
    }
    
    /** Sets the value for {@link ConditionReceive#received received}
     * @param received A String with the new value for {@link ConditionReceive#received received} */
    public void setReceived(String received) {
        this.received = received;
    }
    
    /** A "receive" condition needs a query, thus this class always returns true
     * @return Always return true  */
    public boolean needsAQuery() {
        return true;
    }
    
    /** Checks if the condition is true by comparing the equality of received and the value obtained from
     * {@link RuleProcessor#getInputQuery() RuleProcessor.getInputQuery()}.
     *
     * @return true if the condition is valid, false otherwise. */
    public boolean checkCondition() {
        
        String name = RuleProcessor.getInputQuery();
        boolean res = received.equals(name);
        String message = "Condition '" + this.name + "' is TRUE";
        
        if (!res) {
            message = "Receive query, which is " + name + ", is not " +
                    received;
        }
        
        Diagnostic.writeLog(Diagnostic.INFO_MODE, message);
        
        return res;
    }
}
