/*
 * Class: Rule
 *
 * $Id: Rule.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.rules;

import es.rediris.aarr.Diagnostic;

import java.util.Iterator;
import java.util.Vector;


/**
 * Implements a Rule, with its conditions and actions, with all the methods needed to
 * access both the conditions and actions
 *
 * @author kan
 */
public class Rule {
    /** the name of the rule */
    String name;

    /** A vector containing the conditions for this rule */
    Vector conditions;

    /** A vector containing the actions for this rule */
    Vector actions;

    /** Inits the Rule object by creating two vectors for the storage of conditions and actions */
    public Rule() {
        conditions = new Vector(5, 1);
        actions = new Vector(5, 1);
    }

    /** Inits the Rule and sets a name

    @param name the name for this rule
    */
    public Rule(String name) {
        this();
        this.name = name;
    }

    /** Returns the name of the rule
    @return A string with the name */
    public String getName() {
        return name;
    }

    /** Sets a new name for this rule
    @param name String with the name */
    public void setName(String name) {
        this.name = name;
    }

    /** Returns an <code>java.util.Iterator</code> Object from the vector of conditions
    @return An Iterator */
    public Iterator getConditions() {
        return conditions.iterator();
    }

    /** Adds a new {@link Condition condition} to the conditions vector
    @param c the {@link Condition condition} to be added */
    public void addCondition(Condition c) {
        conditions.addElement(c);
    }

    /** Remove specified {@link Condition condition} from the conditions vector

    @param c The condition to be removed */
    public void delCondition(Condition c) {
        conditions.remove(c);
    }

    /** Returns the number of conditions stored inside the conditions vector

    @return the number of conditions (integer) */
    public int getConditionsSize() {
        return conditions.size();
    }

    /** Returns an <code>java.util.Iterator</code> Object from the vector of Actions

    @return An Iterator */
    public Iterator getActions() {
        return actions.iterator();
    }

    /** Adds a new {@link Action action}
    @param c the action to be added */
    public void addAction(Action c) {
        actions.addElement(c);
    }

    /** Remove specified {@link Action} from the conditions vector

    @param c The condition to be removed */
    public void delAction(Action c) {
        actions.remove(c);
    }

    /** Returns the number of actions stored inside the actions vector

    @return the number of actions (integer) */
    public int getActionsSize() {
        return actions.size();
    }

    /** Checks conditions inside this rule and perform actions if the conditions are satisfied

    @return A String saying if the conditions were satisfied */
    public String execute() {
        boolean execute = true;
        String res = null;
        Iterator iterCond = getConditions();
        int index = 1;

        while (execute && iterCond.hasNext()) {
            Condition cond = (Condition) iterCond.next();

            if (cond.getName().equals("")) {
                Diagnostic.writeLog(Diagnostic.INFO_MODE,
                    "Checking condition #" + index);
            } else {
                Diagnostic.writeLog(Diagnostic.INFO_MODE,
                    "Checking condition '" + cond.getName() + "'");
            }

            index++;
            execute &= cond.checkCondition();
        }

        if (execute) {
            String message = "All conditions from '" + getName() +
                "' rule are OK";

            if (getName().equals("")) {
                message = "All conditions from this rule are OK";
            }

            Diagnostic.writeLog(Diagnostic.INFO_MODE, message);

            Iterator iterAct = getActions();
            index = 1;

            while (iterAct.hasNext()) {
                Action action = (Action) iterAct.next();
                String nameAction = action.getName();

                if (nameAction.equals("")) {
                    Diagnostic.writeLog(Diagnostic.INFO_MODE,
                        "Executing action #" + index);
                } else {
                    Diagnostic.writeLog(Diagnostic.INFO_MODE,
                        "Executing action '" + nameAction + "'");
                }

                String nextState = action.execute();
                boolean finalState = action.isEndState();

                if (finalState) {
                    RuleProcessor.endExecution();
                } else {
                    if (nextState != null) {
                        res = nextState;
                    }
                }

                index++;
            }
        }

        return res;
    }
}
