/*
 * Class: State
 *
 * $Id: State.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.rules;

import es.rediris.aarr.Diagnostic;

import java.util.Iterator;
import java.util.Vector;


/**
 * This class is used for storing and executing states depending on a set of rules from a {@link Ruleset Ruleset}.
 *
 * @author kan
 */
public class State {
    /** The name of the State */
    String name;

    /** A set of rules */
    Vector rules;

    /** The main constructor creates a new vector for storing the rules and sets the name of the state
     * @param name the name for the state */
    public State(String name) {
        rules = new Vector(10, 1);
        this.name = name;
    }

    /** This method returns the name of the state.
     * @return A string with the name */
    public String getName() {
        return name;
    }

    /** Sets a new name for the state
     * @param name A string with the name for the state */
    public void setName(String name) {
        this.name = name;
    }

    /** Returns an <code>java.util.Iterator</code> from the vector containing the rules in the current state.
     * @return A <code>java.util.Iterator</code> object */
    public Iterator getIterator() {
        return rules.iterator();
    }

    /** Returns the number of rules in this state
     * @return An integer */
    public int numRules() {
        return rules.size();
    }

    /** Adds a new rule to the {@link State#rules rules} vector
     * @param rule A {@link Rule Rule} object */
    public void addRule(Rule rule) {
        rules.addElement(rule);
    }

    /** Returns the rule at the given position of the {@link State#rules rules} vector
     * @param index Position of the rule
     * @return A {@link Rule Rule} object */
    public Rule getElementAt(int index) {
        return (Rule) rules.elementAt(index);
    }

    /** Removes a rule at the given position from the {@link State#rules rules} vector
     * @param index Position of the rule to be removed */
    public void delRule(int index) {
        rules.remove(index);
    }

    /** Executes (ckecks) all the {@link State#rules rules} in the current State and
     * uses the {@link Diagnostic Diagnostic} module to display the result of the check
     * @return A string with the result of the check */
    public String executeState() {
        String res = getName();
        Iterator iterRules = getIterator();
        int index = 1;

        while (res.equals(getName()) && iterRules.hasNext()) {
            Rule rule = (Rule) iterRules.next();

            if (rule.getName().equals("")) {
                Diagnostic.writeLog(Diagnostic.INFO_MODE,
                    "Checking rule #" + index++);
            } else {
                Diagnostic.writeLog(Diagnostic.INFO_MODE,
                    "Checking rule '" + rule.getName() + "'");
            }

            String nextState = rule.execute();

            if (nextState != null) {
                res = nextState;
            }
        }

        return res;
    }
}
