package data.org.opensaml;

import junit.framework.TestCase;

import org.apache.xml.security.signature.XMLSignature;
import org.opensaml.QName;
import org.opensaml.SAMLAction;
import org.opensaml.SAMLAttributeDesignator;
import org.opensaml.SAMLAttributeQuery;
import org.opensaml.SAMLAuthenticationQuery;
import org.opensaml.SAMLAuthenticationStatement;
import org.opensaml.SAMLAuthorityBinding;
import org.opensaml.SAMLAuthorizationDecisionQuery;
import org.opensaml.SAMLConfig;
import org.opensaml.SAMLException;
import org.opensaml.SAMLNameIdentifier;
import org.opensaml.SAMLRequest;
import org.opensaml.SAMLResponse;
import org.opensaml.SAMLSOAPBinding;
import org.opensaml.SAMLSubject;
import org.opensaml.XML;

import java.io.FileInputStream;
import java.io.IOException;

import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.UnrecoverableKeyException;

import java.util.Arrays;
import java.util.List;


public class SOAPBindingTest extends TestCase {
    private String path = "data/org/opensaml/test.jks";
    private String alias = "mykey";
    private String password = "opensaml";
    private KeyStore ks = null;

    /**
     * Constructor for POSTProfileTest.
     * @param arg0
     */
    public SOAPBindingTest(String arg0) {
        super(arg0);
        System.out.println("Starting test");
    }

    public static void main(String[] args) {
        junit.textui.TestRunner.run(SOAPBindingTest.class);
    }

    /**
     * @see TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        ks = KeyStore.getInstance("JKS");
        ks.load(new FileInputStream(path), password.toCharArray());

        SAMLConfig config = SAMLConfig.instance();
        config.setProperty("ssl-alias", alias);
        config.setProperty("ssl-keystore-pwd", password);
        config.setProperty("ssl-key-pwd", password);
    }

    /**
     * @see TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        super.tearDown();
    }

    public void testSOAPBinding() throws Exception {
        SAMLAuthorityBinding binding = new SAMLAuthorityBinding(SAMLSOAPBinding.SAML_SOAP_HTTPS,
                "http://127.0.0.1:80", // http://127.0.0.1:8080/aarr/servlet/aarr.as.ASServlet
                new QName(XML.SAML_NS, "AttributeStatement"));

        SAMLSOAPBinding b = new SAMLSOAPBinding();

		System.out.println("********* Attribute");
        SAMLRequest r = createAttributeQuery("Candido Rodriguez", "us.es",
                new String[] {"eduPersonEntitlement"}, false);
        getResponse(binding, b, r);
		System.out.println("--------------------------");
//        SAMLRequest r3 = createAttributeQuery("Candido Rodriguez", "us.es",
//                new String[] { "universityPAPI", "linux" }, false);
//        getResponse(binding, b, r3);

		System.out.println("********* AuthorizationDecision");
		SAMLRequest r4=createAuthorizationQuery("Candido Rodriguez","us.es","http://sugus.eii.us.es",SAMLAction.SAML_ACTION_NAMESPACE_RWEDC_NEG,"Read",false);
		getResponse(binding,b,r4); 
		System.out.println("--------------------------");

		System.out.println("********* Authentication");
		SAMLRequest r2=createAuthenticationQuery("Candido Rodriguez","us.es",SAMLAuthenticationStatement.AuthenticationMethod_Password,false);
		System.out.println("--------------------------");
		getResponse(binding,b,r2); 
		System.out.println("--------------------------");

    }

    private void getResponse(SAMLAuthorityBinding binding, SAMLSOAPBinding b,
        SAMLRequest r) throws IOException, SAMLException {
        try {
            SAMLResponse r2 = b.send(binding, r);
            r2.toStream(System.err);
            System.err.println();
        } catch (SAMLException ex) {
            ex.printStackTrace();

            if ((ex.getException() != null) &&
                    ex.getException() instanceof SAMLException) {
                ((SAMLException) ex.getException()).toStream(System.err);
            } else {
                ex.toStream(System.err);
            }

            throw ex;
        }
    }

    private SAMLRequest createAttributeQuery(String name, String domain,
        String[] attrs, boolean signed) throws SAMLException {
        List attrList = null;

        if (attrs != null) {
			SAMLAttributeDesignator[] attrArray = new SAMLAttributeDesignator[attrs.length];

            for (int i = 0; i < attrs.length; i++) {
                attrArray[i] = new SAMLAttributeDesignator(attrs[i], domain);
            }

            attrList = Arrays.asList(attrArray);
        }

        SAMLRequest r = new SAMLRequest(null,
                new SAMLAttributeQuery(
                	new SAMLSubject(
                		new SAMLNameIdentifier(name, domain, null), 
                		null, null, null), 
					"http://www.foo.com/", 
					attrList), 
				null, 
				null);

        if (signed) {
            try {
                r.sign(XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA1,
                    ks.getKey(alias, password.toCharArray()),
                    Arrays.asList(ks.getCertificateChain(alias)));
            } catch (UnrecoverableKeyException e1) {
            } catch (KeyStoreException e2) {
            } catch (NoSuchAlgorithmException e3) {
            }
        }

        return r;
    }

    private SAMLRequest createAuthenticationQuery(String name, String domain,
        String authMethod, boolean signed) throws SAMLException {
        SAMLRequest r = new SAMLRequest(null,
                new SAMLAuthenticationQuery(new SAMLSubject(
                        new SAMLNameIdentifier(name, domain, null), null, null,
                        null), authMethod), null, null);

        if (signed) {
            try {
                r.sign(XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA1,
                    ks.getKey(alias, password.toCharArray()),
                    Arrays.asList(ks.getCertificateChain(alias)));
            } catch (UnrecoverableKeyException e1) {
            } catch (KeyStoreException e2) {
            } catch (NoSuchAlgorithmException e3) {
            }
        }

        return r;
    }


	private SAMLRequest createAuthorizationQuery(String name, String domain,
		String uri, String actionUri, String actionData, boolean signed) throws SAMLException {
			SAMLAction action=new SAMLAction(actionUri,actionData);
		SAMLRequest r = new SAMLRequest(null,
				new SAMLAuthorizationDecisionQuery(
					new SAMLSubject(
						new SAMLNameIdentifier(name, domain, null),
						null, null,	null), 
					uri, Arrays.asList(new SAMLAction[]{action}), null),
				null,null);

		if (signed) {
			try {
				r.sign(XMLSignature.ALGO_ID_SIGNATURE_RSA_SHA1,
					ks.getKey(alias, password.toCharArray()),
					Arrays.asList(ks.getCertificateChain(alias)));
			} catch (UnrecoverableKeyException e1) {
			} catch (KeyStoreException e2) {
			} catch (NoSuchAlgorithmException e3) {
			}
		}

		return r;
	}
}
